==> scanning-sdk-0.12.1-sources.jar: com/estimote/scanning_sdk/dagger/ScanSettingsTransformersModule.kt <==
package com.estimote.scanning_sdk.dagger

import android.bluetooth.le.ScanFilter
import android.bluetooth.le.ScanSettings
import com.estimote.scanning_sdk.packet_provider.scanner.filter_transformers.*
import com.estimote.scanning_sdk.packet_provider.scanner.settings_transformers.DefaultScanSettingsTransformer
import com.estimote.scanning_sdk.packet_provider.scanner.settings_transformers.SamsungScanSettingsTransformer
import com.estimote.scanning_sdk.packet_provider.scanner.settings_transformers.ScanSettingsTransformerProvider
import com.estimote.scanning_sdk.settings.ScanSettingsVisitor
import dagger.Module
import dagger.Provides
import javax.inject.Named

@Module
internal class ScanSettingsTransformersModule(private val manufacturerId: String) {

    @Provides
    @EstimoteScanningSdkScope
    fun provideEstimoteSettingsToFilterTransformer(): ScanSettingsVisitor<@JvmWildcard List<ScanFilter>> =
            DefaultScanFiltersTransformer(
                    ToIBeaconFilterTransformer(HardwareFilterBuilderFactory()),
                    ToEddystoneFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                    ToEstimoteTelemetryFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                    ToEstimoteLocationFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                    ToEstimoteMeshFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                    ToMirrorFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                    ToUwbFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                    ToNearableFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                    ToConfigurableDeviceFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()))

    @Provides
    @EstimoteScanningSdkScope
    @Named("DefaultSettingsTransformer")
    fun provideDefaultEstimoteSettingsToScanSettingsTransformer(): ScanSettingsVisitor<ScanSettings> =
            DefaultScanSettingsTransformer()


    @Provides
    @EstimoteScanningSdkScope
    @Named("SamsungSettingsTransformer")
    fun provideSamsungEstimoteSettingsToScanSettingsTransformer(): ScanSettingsVisitor<ScanSettings> =
            SamsungScanSettingsTransformer()

    @Provides
    @EstimoteScanningSdkScope
    fun provideScanSettingsTransformerProvider(
            @Named("DefaultSettingsTransformer") defaultTransformer: ScanSettingsVisitor<ScanSettings>,
            @Named("SamsungSettingsTransformer") samsungTransformer: ScanSettingsVisitor<ScanSettings>): ScanSettingsTransformerProvider =
            ScanSettingsTransformerProvider(manufacturerId, defaultTransformer, samsungTransformer)
}

==> scanning-sdk-0.13.0-sources.jar: com/estimote/scanning_sdk/dagger/ScanSettingsTransformersModule.kt <==
package com.estimote.scanning_sdk.dagger

import android.bluetooth.le.ScanFilter
import com.estimote.scanning_sdk.packet_provider.scanner.filter_transformers.*
import com.estimote.scanning_sdk.packet_provider.scanner.settings_transformers.ScanSettingsTransformerProvider
import com.estimote.scanning_sdk.settings.ScanSettingsVisitor
import dagger.Module
import dagger.Provides

@Module
internal class ScanSettingsTransformersModule(private val androidApiVersion: Int,
                                              private val manufacturerId: String) {

    @Provides
    @EstimoteScanningSdkScope
    fun provideEstimoteSettingsToFilterTransformer(): ScanSettingsVisitor<@JvmWildcard List<ScanFilter>> =
            DefaultScanFiltersTransformer(
                    ToIBeaconFilterTransformer(HardwareFilterBuilderFactory()),
                    ToEddystoneFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                    ToEstimoteTelemetryFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                    ToEstimoteLocationFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                    ToEstimoteMeshFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                    ToMirrorFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                    ToUwbFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                    ToNearableFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                    ToConfigurableDeviceFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()))

    @Provides
    @EstimoteScanningSdkScope
    fun provideScanSettingsTransformerProvider(): ScanSettingsTransformerProvider = ScanSettingsTransformerProvider(androidApiVersion, manufacturerId)
}
